==> scanbot_sdk-2.12.1.tar.gz: ios/Classes/Classical Component/Configurations/DocumentScannerConfiguration.swift <==
//
//  DocumentScannerConfiguration.swift
//  scanbot_sdk
//
//  Created by Seifeddine Bouzid on 29.03.23.
//

import Foundation
import ScanbotSDK

struct DocumentScannerConfiguration {
    
    var flashEnabled: Bool?
    var zoomConfiguration: SBSDKBaseScannerZoomConfiguration?
    var requiredAspectRatios: [SBSDKAspectRatio]?
    var scannerConfiguration: ScannerConfiguration?
    var polygonConfiguration: PolygonConfiguration?
    
    init() { }
    
    init(_ arguments: [String: Any?]?) {
        if let arguments {
            self = DocumentScannerConfiguration.parseArguments(arguments)
        }
    }
    
    private static func parseArguments(_ arguments: [String: Any?]) -> DocumentScannerConfiguration {
        var configuration = DocumentScannerConfiguration()
        
        if let flashEnabled = arguments["flashEnabled"] as? Bool {
            configuration.flashEnabled = flashEnabled
        }
        
        if let cameraZoomFactor = arguments["cameraZoomFactor"] as? CGFloat {
            let zoomConfig = SBSDKBaseScannerZoomConfiguration.default()
            zoomConfig.initialZoomFactor = cameraZoomFactor
            configuration.zoomConfiguration = zoomConfig
        }
        
        if let requiredAspectRatios = arguments["requiredAspectRatios"] as? [String: Any] {
            var array: [SBSDKAspectRatio] = []
            requiredAspectRatios.forEach { (_, _) in
                if let aspectRatio = SBSDKAspectRatio.init(from: requiredAspectRatios) {
                    array.append(aspectRatio)
                }
            }
            configuration.requiredAspectRatios = array
        }
        
        if let polygonConfiguration = arguments["contourConfiguration"] as? [String: Any] {
            configuration.polygonConfiguration = PolygonConfiguration(polygonConfiguration)
        }
        
        if let scannerConfiguration = arguments["scannerConfiguration"] as? [String: Any] {
            configuration.scannerConfiguration = ScannerConfiguration(scannerConfiguration)
        }
        
        return configuration
    }
    
    struct ScannerConfiguration {
        
        var textHintBadAngles: String = ""
        var textHintTooDark: String = ""
        var textHintTooNoisy: String = ""
        var textHintTooSmall: String = ""
        var textHintOffCenter: String = ""
        var textHintNothingDetected: String = ""
        var textHintOKManualScan: String = ""
        var textHintOKAutoShutter: String = ""
        var textHintEnergySavingActive: String = ""
        var textHintBadAspectRatio: String = ""
        var hideSnapButton: Bool = true
        var acceptedSizeScore: Double?
        var acceptedAngleScore: Double?
        var ignoreBadAspectRatio: Bool?
        var autoSnappingSensitivity: CGFloat?
        var detectDocumentAfterSnap: Bool?
        
        init() { }
        
        init(_ arguments: [String: Any]) {
            self = ScannerConfiguration.parseArguments(arguments: arguments)
        }
        
        private static func parseArguments(arguments: [String: Any]) -> ScannerConfiguration {
            var configuration = ScannerConfiguration()
            
            if let acceptedSizeScore =  arguments["acceptedSizeScore"] as? Double {
                configuration.acceptedSizeScore = acceptedSizeScore
            }
            
            if let acceptedAngleScore =  arguments["acceptedAngleScore"] as? Double {
                configuration.acceptedAngleScore = acceptedAngleScore
            }
            
            if let ignoreBadAspectRatio = arguments["ignoreBadAspectRatio"] as? Bool {
                configuration.ignoreBadAspectRatio = ignoreBadAspectRatio
            }
            
            if let autoSnappingSensitivity = arguments["autoSnappingSensitivity"] as? Double {
                configuration.autoSnappingSensitivity = autoSnappingSensitivity
            }
            
            if let detectDocumentAfterSnap = arguments["detectDocumentAfterSnap"] as? Bool {
                configuration.detectDocumentAfterSnap = detectDocumentAfterSnap
            }
            
            return configuration
        }
    }
    
    struct PolygonConfiguration {
        
        var polygonAutoSnapProgressEnabled: Bool?
        var polygonLineWidth: CGFloat?
        var polygonAutoSnapProgressLineWidth: CGFloat?
        var polygonCornerRadius: CGFloat?
        var polygonFillColorAccepted: UIColor?
        var polygonFillColorRejected: UIColor?
        var polygonLineColorAccepted: UIColor?
        var polygonLineColorRejected: UIColor?
        var polygonAutoSnapProgressColor: UIColor?
        
        init() { }
        
        init(_ arguments: [String: Any]) {
            self = PolygonConfiguration.parseArguments(arguments: arguments)
        }
        
        private static func parseArguments(arguments: [String: Any]) -> PolygonConfiguration {
            var configuration = PolygonConfiguration()
            
            if let polygonAutoSnapProgressEnabled = arguments["autoSnapProgressEnabled"] as? Bool {
                configuration.polygonAutoSnapProgressEnabled = polygonAutoSnapProgressEnabled
            }
            
            if let polygonLineWidth = arguments["strokeWidth"] as? Double {
                configuration.polygonLineWidth = polygonLineWidth
            }
            
            if let polygonAutoSnapProgressLineWidth = arguments["autoSnapProgressStrokeWidth"] as? Double {
                configuration.polygonAutoSnapProgressLineWidth = polygonAutoSnapProgressLineWidth
            }
            
            if let polygonCornerRadius = arguments["cornerRadius"] as? Double {
                configuration.polygonCornerRadius = polygonCornerRadius
            }
            
            if let polygonFillColorAccepted = arguments["fillOkColor"] as? String {
                configuration.polygonFillColorAccepted = UIColor(hexString: polygonFillColorAccepted)
            }
            
            if let polygonFillColorRejected = arguments["fillColor"] as? String {
                configuration.polygonFillColorRejected = UIColor(hexString: polygonFillColorRejected)
            }
            
            if let polygonLineColorAccepted = arguments["strokeOkColor"] as? String {
                configuration.polygonLineColorAccepted = UIColor(hexString: polygonLineColorAccepted)
            }
            
            if let polygonLineColorRejected = arguments["strokeColor"] as? String {
                configuration.polygonLineColorRejected = UIColor(hexString: polygonLineColorRejected)
            }
            
            if let polygonAutoSnapProgressColor = arguments["autoSnapProgressStrokeColor"] as? String {
                configuration.polygonAutoSnapProgressColor = UIColor(hexString: polygonAutoSnapProgressColor)
            }
            return configuration
        }
    }
}

==> scanbot_sdk-2.13.0.tar.gz: ios/Classes/Classical Component/Configurations/DocumentScannerConfiguration.swift <==
//
//  DocumentScannerConfiguration.swift
//  scanbot_sdk
//
//  Created by Seifeddine Bouzid on 29.03.23.
//

import Foundation
import ScanbotSDK

struct DocumentScannerConfiguration {
    
    var flashEnabled: Bool?
    var zoomConfiguration: SBSDKBaseScannerZoomConfiguration?
    var scannerConfiguration: ScannerConfiguration?
    var polygonConfiguration: PolygonConfiguration?
    
    init() { }
    
    init(_ arguments: [String: Any?]?) {
        if let arguments {
            self = DocumentScannerConfiguration.parseArguments(arguments)
        }
    }
    
    private static func parseArguments(_ arguments: [String: Any?]) -> DocumentScannerConfiguration {
        var configuration = DocumentScannerConfiguration()
        
        if let flashEnabled = arguments["flashEnabled"] as? Bool {
            configuration.flashEnabled = flashEnabled
        }
        
        if let cameraZoomFactor = arguments["cameraZoomFactor"] as? CGFloat {
            let zoomConfig = SBSDKBaseScannerZoomConfiguration.default()
            zoomConfig.initialZoomFactor = cameraZoomFactor
            configuration.zoomConfiguration = zoomConfig
        }
        
        if let polygonConfiguration = arguments["contourConfiguration"] as? [String: Any] {
            configuration.polygonConfiguration = PolygonConfiguration(polygonConfiguration)
        }
        
        if let scannerConfiguration = arguments["scannerConfiguration"] as? [String: Any] {
            configuration.scannerConfiguration = ScannerConfiguration(scannerConfiguration)
        }
        
        return configuration
    }
    
    struct ScannerConfiguration {
        
        var textHintBadAngles: String = ""
        var textHintTooDark: String = ""
        var textHintTooNoisy: String = ""
        var textHintTooSmall: String = ""
        var textHintOffCenter: String = ""
        var textHintNothingDetected: String = ""
        var textHintOKManualScan: String = ""
        var textHintOKAutoShutter: String = ""
        var textHintEnergySavingActive: String = ""
        var textHintBadAspectRatio: String = ""
        var hideSnapButton: Bool = true
        var acceptedSizeScore: Double?
        var autoSnapEnabled: Bool?
        var acceptedAngleScore: Double?
        var ignoreBadAspectRatio: Bool?
        var autoSnappingSensitivity: CGFloat?
        var detectDocumentAfterSnap: Bool?
        var requiredAspectRatios: [SBSDKAspectRatio]?
        
        init() { }
        
        init(_ arguments: [String: Any]) {
            self = ScannerConfiguration.parseArguments(arguments: arguments)
        }
        
        private static func parseArguments(arguments: [String: Any]) -> ScannerConfiguration {
            var configuration = ScannerConfiguration()
            
            if let acceptedSizeScore =  arguments["acceptedSizeScore"] as? Double {
                configuration.acceptedSizeScore = acceptedSizeScore
            }
            
            if let autoSnapEnabled =  arguments["autoSnapEnabled"] as? Bool {
                configuration.autoSnapEnabled = autoSnapEnabled
            }
            
            if let acceptedAngleScore =  arguments["acceptedAngleScore"] as? Double {
                configuration.acceptedAngleScore = acceptedAngleScore
            }
            
            if let ignoreBadAspectRatio = arguments["ignoreBadAspectRatio"] as? Bool {
                configuration.ignoreBadAspectRatio = ignoreBadAspectRatio
            }
            
            if let autoSnappingSensitivity = arguments["autoSnapSensitivity"] as? Double {
                configuration.autoSnappingSensitivity = autoSnappingSensitivity
            }
            
            if let detectDocumentAfterSnap = arguments["detectDocumentAfterSnap"] as? Bool {
                configuration.detectDocumentAfterSnap = detectDocumentAfterSnap
            }
            
            if let requiredAspectRatios = arguments["requiredAspectRatios"] as? [[String: Any]] {
                var array: [SBSDKAspectRatio] = []
                requiredAspectRatios.forEach { aspectRatioJson in
                    if let aspectRatio = SBSDKAspectRatio.init(from: aspectRatioJson){
                        array.append(aspectRatio)
                    }
                }
                configuration.requiredAspectRatios = array
                return configuration
            }
            
            return configuration
        }
    }
    
    struct PolygonConfiguration {
        
        var polygonAutoSnapProgressEnabled: Bool?
        var polygonLineWidth: CGFloat?
        var polygonAutoSnapProgressLineWidth: CGFloat?
        var polygonCornerRadius: CGFloat?
        var polygonFillColorAccepted: UIColor?
        var polygonFillColorRejected: UIColor?
        var polygonLineColorAccepted: UIColor?
        var polygonLineColorRejected: UIColor?
        var polygonAutoSnapProgressColor: UIColor?
        
        init() { }
        
        init(_ arguments: [String: Any]) {
            self = PolygonConfiguration.parseArguments(arguments: arguments)
        }
        
        private static func parseArguments(arguments: [String: Any]) -> PolygonConfiguration {
            var configuration = PolygonConfiguration()
            
            if let polygonAutoSnapProgressEnabled = arguments["autoSnapProgressEnabled"] as? Bool {
                configuration.polygonAutoSnapProgressEnabled = polygonAutoSnapProgressEnabled
            }
            
            if let polygonLineWidth = arguments["strokeWidth"] as? Double {
                configuration.polygonLineWidth = polygonLineWidth
            }
            
            if let polygonAutoSnapProgressLineWidth = arguments["autoSnapProgressStrokeWidth"] as? Double {
                configuration.polygonAutoSnapProgressLineWidth = polygonAutoSnapProgressLineWidth
            }
            
            if let polygonCornerRadius = arguments["cornerRadius"] as? Double {
                configuration.polygonCornerRadius = polygonCornerRadius
            }
            
            if let polygonFillColorAccepted = arguments["fillOkColor"] as? String {
                configuration.polygonFillColorAccepted = UIColor(hexString: polygonFillColorAccepted)
            }
            
            if let polygonFillColorRejected = arguments["fillColor"] as? String {
                configuration.polygonFillColorRejected = UIColor(hexString: polygonFillColorRejected)
            }
            
            if let polygonLineColorAccepted = arguments["strokeOkColor"] as? String {
                configuration.polygonLineColorAccepted = UIColor(hexString: polygonLineColorAccepted)
            }
            
            if let polygonLineColorRejected = arguments["strokeColor"] as? String {
                configuration.polygonLineColorRejected = UIColor(hexString: polygonLineColorRejected)
            }
            
            if let polygonAutoSnapProgressColor = arguments["autoSnapProgressStrokeColor"] as? String {
                configuration.polygonAutoSnapProgressColor = UIColor(hexString: polygonAutoSnapProgressColor)
            }
            return configuration
        }
    }
}
